@@ -68,15 +68,15 @@ struct _GnomeFontSelectionClass
 
 enum {FONT_SET, LAST_SIGNAL};
 
-/* This is the initial and maximum height of the preview entry (it expands
-   when large font sizes are selected). Initial height is also the minimum. */
+/* This is the initial height of the preview entry (it expands when large
+   font sizes are selected). Initial height is also the minimum. */
 #define MIN_PREVIEW_HEIGHT 44
 #define MAX_PREVIEW_HEIGHT 300
 
 /* These are what we use as the standard font sizes, for the size combo.
    Note that when using points we still show these integer point values but
    we work internally in decipoints (and decipoint values can be typed in). */
-static gchar * font_sizes[] = {
+static const gchar * font_sizes[] = {
   "8", "9", "10", "11", "12", "13", "14", "16", "18", "20", "22", "24", "26", "28",
   "32", "36", "40", "48", "56", "64", "72"
 };
@@ -99,7 +99,7 @@ static GtkHBoxClass *gfs_parent_class = NULL;
 static guint gfs_signals[LAST_SIGNAL] = {0};
 
 GType
-gnome_font_selection_get_type ()
+gnome_font_selection_get_type (void)
 {
 	static GType type = 0;
 	if (!type) {
@@ -324,7 +324,7 @@ gnome_font_selection_destroy (GtkObject *object)
 }
 
 GtkWidget *
-gnome_font_selection_new ()
+gnome_font_selection_new (void)
 {
 	GnomeFontSelection * fontsel;
 	GtkTreeModel *model;
@@ -624,7 +624,7 @@ static void gnome_font_preview_update (GnomeFontPreview * preview);
 static GtkImageClass *gfp_parent_class = NULL;
 
 GType
-gnome_font_preview_get_type ()
+gnome_font_preview_get_type (void)
 {
 	static GType type = 0;
 	if (!type) {
