@@ -50,7 +50,7 @@ gpa_widget_get_type (void)
 			sizeof (GPAWidget),
 			0,
 			(GInstanceInitFunc) gpa_widget_init,
-			NULL,
+			NULL
 		};
 		type = g_type_register_static (GTK_TYPE_BIN, "GPAWidget", &info, 0);
 	}
@@ -87,8 +87,6 @@ gpa_widget_finalize (GObject *object)
 {
 	GPAWidget *gpw;
 
-	return;
-	
 	gpw = (GPAWidget *) object;
 
 	if (gpw->config)
@@ -143,7 +141,7 @@ gpa_widget_construct (GPAWidget *gpw, GnomePrintConfig *config)
 }
 
 GtkWidget *
-gpa_widget_new (GtkType type, GnomePrintConfig *config)
+gpa_widget_new (GType type, GnomePrintConfig *config)
 {
 	GPAWidget *gpw;
 
